<?php

namespace Drupal\content_block\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form to configure Content Block settings.
 */
class ContentBlockSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['content_block.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_block_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('content_block.settings');

    $form['entities_classes_to_ignore'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Entities Classes to Ignore'),
      '#description' => $this->t('Enter the fully qualified class names of the entities to ignore, one per line.'),
      '#default_value' => implode("\n", $config->get('entities_classes_to_ignore') ?? []),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('content_block.settings')
      ->set('entities_classes_to_ignore', array_filter(array_map('trim', explode("\n", $form_state->getValue('entities_classes_to_ignore')))))
      ->save();

    parent::submitForm($form, $form_state);
  }

}