<?php

namespace Drupal\content_block\LayoutRender;

use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Class DynamicQueryHelper.
 */
class LayoutRender {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new DynamicQueryHelper object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Build a layout with the given entities.
   *
   * @param array $entities
   *   The entities to render.
   * @param array $configuration
   *   The configuration for the layout.
   *
   * @return array
   *   A render array for the layout.
   */
  public function buildLayout($entities, $configuration) {
    $build = [];

    foreach ($configuration as $key => $value) {
      $option_name = str_replace('_content_block_option', '', $key);
      $$option_name = $value;
    }

    $view_builder = $this->entityTypeManager->getViewBuilder($entity_type);

    // Initialize regions array.
    $column_data = array_fill(0, $columns, []);
    $i = 0;
    // Split the entities into columns.
    foreach ($entities as $entity) {
      $column_data[$i % $columns][] = $view_builder->view($entity, $view_mode);
      $i++;
    }

    // Get layout information.
    $layoutInfo = $this->getLayoutInfo($columns);
    $region_names = $layoutInfo['region_names'];
    $wrapper_classes = $layoutInfo['wrapper_classes'];
    $library_name = $layoutInfo['library_name'];

    // Build regions render array.
    foreach ($column_data as $index => $items) {
      $region_name = $region_names[$index];
      $regions[$region_name] = [
        '#type' => 'container',
        '#attributes' => ['class' => ['layout__region', 'layout__region--' . $region_name]],
        'content' => [],
      ];

      // Add each entity render array inside the region.
      foreach ($items as $item) {
        $regions[$region_name]['content'][] = $item;
      }
    }

    // Build the layout render array and embed the regions inside.
    $build = [
      '#type' => 'container',
      'contenedor' => [
        '#type' => 'container',
        '#attributes' => [
          'class' => ['layout', $wrapper_classes],
        ],
        'content' => $regions,
      ],
    ];

    $build['#attached']['library'][] = 'layout_discovery/' . $library_name;
    return $build;
  }

  /**
   * Get the layout information for the given number of columns.
   *
   * @param [type] $columns
   *   The number of columns in the layout.
   *
   * @return array
   *   An array with the layout information.
   */
  private function getLayoutInfo($columns) {
    switch ($columns) {

      case 1:
        return [
          'layout_id' => 'layout_onecol',
          'region_names' => ['content'],
          'wrapper_classes' => 'layout--onecol',
          'library_name' => 'onecol',
        ];

      case 2:
        return [
          'layout_id' => 'layout_twocol',
          'region_names' => ['first', 'second'],
          'wrapper_classes' => 'layout--twocol',
          'library_name' => 'twocol',
        ];

      case 3:
        return [
          'layout_id' => 'layout_threecol',
          'region_names' => ['first', 'second', 'third'],
          'wrapper_classes' => 'layout--threecol-33-34-33',
          'library_name' => 'threecol_33_34_33',
        ];

      default:
        return [
          'layout_id' => 'layout_onecol',
          'region_names' => ['content'],
          'wrapper_classes' => 'layout--onecol',
          'library_name' => 'onecol',
        ];
    }
  }

}
