<?php

namespace Drupal\content_block\Plugin\ContentBlockOption;

use Drupal\content_block\Plugin\ContentBlockOptionBase;
use Drupal\Core\Entity\Query\QueryInterface;

/**
 * Provides a ContentBlockOption plugin for entities columns layout.
 *
 * @ContentBlockOption(
 *   id = "columns_content_block_option",
 *   label = @Translation("Columns Content Block Option"),
 *   description = @Translation("Applies conditions for entities columns layouts."),
 *   weight = 5
 * )
 */
class ColumnsContentBlockOption extends ContentBlockOptionBase {

  /**
   * Gets the form field for the option.
   *
   * @param mixed $default_value
   *   The default value for the form field.
   *
   * @return array
   *   The form field.
   */
  public function getFormField($default_value = NULL): array {
    return [
      '#type' => 'number',
      '#title' => $this->t('Number of Columns'),
      '#default_value' => $default_value ?? 3,
      '#min' => 1,
      '#max' => 3,
      '#parents' => ['wrapper', $this->getPluginId()],
      '#attributes' => [
        'style' => 'width: 300px;',
      ],
    ];
  }

  /**
   * Adds a condition to the query.
   *
   * @param \Drupal\Core\Entity\Query\QueryInterface $query
   *   The entity query to modify.
   * @param array $param
   *   The parameters for the block.
   */
  public function addConditionToQuery(QueryInterface &$query, string $param): void {}

}
