<?php

namespace Drupal\content_block\Plugin\ContentBlockOption;

use Drupal\content_block\Plugin\ContentBlockOptionBase;
use Drupal\Core\Entity\Query\QueryInterface;

/**
 * Provides a ContentBlockOption plugin for sorting entities.
 *
 * @ContentBlockOption(
 *   id = "sort_content_block_option",
 *   label = @Translation("Sort Content Block Option"),
 *   description = @Translation("Applies conditions for entities sorting."),
 *   weight = 3
 * )
 */
class SortContentBlockOption extends ContentBlockOptionBase {

  /**
   * Gets the form field for the option.
   *
   * @param mixed $default_value
   *   The default value for the form field.
   *
   * @return array
   *   The form field.
   */
  public function getFormField($default_value = NULL): array {
    return [
      '#type' => 'select',
      '#title' => $this->t('Sort'),
      '#options' => [
        'created_asc' => $this->t('Created (Ascending)'),
        'created_desc' => $this->t('Created (Descending)'),
        'title_asc' => $this->t('Title (Ascending)'),
        'title_desc' => $this->t('Title (Descending)'),
        'random' => $this->t('Random'),
      ],
      '#default_value' => $default_value ?? 'created_desc',
      '#parents' => ['wrapper', $this->getPluginId()],
      '#attributes' => [
        'style' => 'width: 300px;',
      ],
    ];
  }

  /**
   * Adds a condition to the query.
   *
   * @param \Drupal\Core\Entity\Query\QueryInterface $query
   *   The entity query to modify.
   * @param array $param
   *   The parameters for the block.
   */
  public function addConditionToQuery(QueryInterface &$query, string $param): void {
    switch ($param) {

      case 'created_asc':
        $query->sort('changed', 'ASC');
        break;

      case 'created_desc':
        $query->sort('changed', 'DESC');
        break;

      case 'title_asc':
        $query->sort('title', 'ASC');
        break;

      case 'title_desc':
        $query->sort('title', 'DESC');
        break;

      case 'random':
        $definitions = $this->entityTypeManager->getDefinitions();

        if (isset($definitions[$this->configuration['entity_type']])) {
          $entity_id_column = $definitions[$this->configuration['entity_type']]->getKey('id');
          if ($entity_id_column) {
            $query->sort($entity_id_column, 'RAND');
          }
        }
        break;
    }
  }

}
