<?php

namespace Drupal\content_block\Plugin;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Component\Utility\SortArray;

/**
 * Manages discovery and instantiation of ContentBlockOption plugins.
 */
class ContentBlockOptionManager extends DefaultPluginManager implements PluginManagerInterface {

  /**
   * Constructs a new ContentBlockOptionManager object.
   *
   * @param string|bool $namespace
   *   The namespace for the plugin.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   The cache backend to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   */
  public function __construct($namespace, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct(
      'Plugin/ContentBlockOption',
      $namespace,
      $module_handler,
      'Drupal\content_block\Plugin\ContentBlockOptionInterface',
      'Drupal\content_block\Annotation\ContentBlockOption'
    );
    $this->alterInfo('content_block_option_info');
    $this->setCacheBackend($cache_backend, 'content_block_option_plugins');
  }

  /**
   * {@inheritdoc}
   */
  public function getDefinitions() {
    $definitions = parent::getDefinitions();

    // Sort definitions by weight.
    uasort($definitions, function ($a, $b) {
      return SortArray::sortByWeightElement($a, $b);
    });

    return $definitions;
  }

}
